@@ -170,6 +170,9 @@ struct _PyGICallableCache
     GHashTable *arg_name_hash;
     gboolean throws;
 
+    /* Index of user_data arg passed to a callable. */
+    gssize user_data_index;
+
     /* Index of user_data arg that can eat variable args passed to a callable. */
     gssize user_data_varargs_index;
 
@@ -180,6 +183,12 @@ struct _PyGICallableCache
      * This is used for the length of PyGIInvokeState.out_values */
     gssize n_to_py_args;
 
+    /* If the callable return value gets used */
+    gboolean has_return;
+
+    /* The type used for returning multiple values or NULL */
+    PyTypeObject* resulttuple_type;
+
     /* Number of out args for g_function_info_invoke that will be skipped
      * when marshaling to Python due to them being implicitly available
      * (list/array length).
